@@ -17,6 +17,8 @@
 """
 Test http checking.
 """
+import os
+import sys
 from .httpserver import HttpServerTest, NoQueryHttpRequestHandler
 from linkcheck.network import iputil
 
@@ -29,20 +31,20 @@ class TestHttp (HttpServerTest):
             url = u"http://localhost:%d/tests/checker/data/" \
                   u"http.html" % self.port
             resultlines = self.get_resultlines("http.html")
-            #self.direct(url, resultlines, recursionlevel=1)
+            self.direct(url, resultlines, recursionlevel=1)
             url = u"http://localhost:%d/tests/checker/data/" \
                   u"http.xhtml" % self.port
             resultlines = self.get_resultlines("http.xhtml")
-            #self.direct(url, resultlines, recursionlevel=1)
-            #self.redirect1_http_test()
-            #self.redirect2_http_test()
-            #self.redirect3_http_test()
+            self.direct(url, resultlines, recursionlevel=1)
+            self.redirect1_http_test()
+            self.redirect2_http_test()
+            self.redirect3_http_test()
             self.redirect4_http_test()
             self.redirect5_http_test()
-            #self.robots_txt_test()
-            #self.robots_txt2_test()
-            #self.swf_test()
-            #self.obfuscate_test()
+            self.robots_txt_test()
+            self.robots_txt2_test()
+            self.swf_test()
+            self.obfuscate_test()
         finally:
             self.stop_server()
 
@@ -159,8 +161,7 @@ class TestHttp (HttpServerTest):
         self.direct(url, resultlines, recursionlevel=5)
 
     def swf_test (self):
-        url = u"http://localhost:%d/tests/checker/data/" \
-              u"test.swf" % self.port
+        url = u"http://localhost:%d/tests/checker/data/test.swf" % self.port
         resultlines = [
             u"url %s" % url,
             u"cache key %s" % url,
@@ -175,8 +176,7 @@ class TestHttp (HttpServerTest):
         self.direct(url, resultlines, recursionlevel=1)
 
     def obfuscate_test (self):
-        import os
-        if os.name != "posix":
+        if os.name != "posix" or sys.platform != 'linux2':
             return
         host = "www.golem.de"
         ip = iputil.resolve_host(host).pop()
