@@ -282,3 +282,19 @@ class TestParser (unittest.TestCase):
 
         self.htmlparser.handler = NamePeeker()
         self.htmlparser.feed(data)
+
+    def test_encoding_detection (self):
+        html = '<meta http-equiv="content-type" content="text/html; charset=UTF-8">'
+        self.encoding_test(html, "utf-8")
+        html = '<meta charset="UTF-8">'
+        self.encoding_test(html, "utf-8")
+        html = '<meta charset="hulla">'
+        self.encoding_test(html, "iso8859-1")
+        html = '<meta http-equiv="content-type" content="text/html; charset=blabla">'
+        self.encoding_test(html, "iso8859-1")
+
+    def encoding_test (self, html, expected):
+        parser = linkcheck.HtmlParser.htmlsax.parser()
+        self.assertEqual(parser.encoding, "iso8859-1")
+        parser.feed(html)
+        self.assertEqual(parser.encoding, expected)
