@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2004-2010 Bastian Kleineidam
+# Copyright (C) 2004-2011 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 """
 Test url routines.
 """
-
+from . import need_network
 import unittest
 import os
 import re
@@ -553,3 +553,7 @@ class TestUrl (unittest.TestCase):
         self.assertFalse(is_safe_domain(u"a_b.example.com"))
         self.assertTrue(is_safe_domain(u"a-b.example.com"))
         self.assertTrue(is_safe_domain(u"x1.example.com"))
+
+    @need_network
+    def test_get_content (self):
+        linkcheck.url.get_content('http://www.debian.org/')
